@@ -66,7 +66,7 @@ class PagesBuilder(BaseBuilder):
             logger.error("An error occured when processing page '{}' in language '{}'"\
                 .format(page['name'], language))
             logger.error(traceback.format_exc())
-            return
+            raise
         self.site.write(output, page['dst'])
 
     def flatten_pages(self, pages):
@@ -121,7 +121,8 @@ class PagesBuilder(BaseBuilder):
         #we update the slugs for the child pages
         for name, slug in new_slugs.items():
             page = page_index[name]
+            extension = page.get('extension', 'html')
             page['slug'] = slug
-            page['dst'] = self.site.get_dst(slug, language)
-            page['link'] = self.site.get_link_dst(slug, language)
+            page['dst'] = self.site.get_dst(slug, language, extension=extension)
+            page['link'] = self.site.get_link_dst(slug, language, extension=extension)
         return pages
